
# tcl_odl schema for canvas items on a displayer canvas


odl_module canvas {

   # The parameters of the module:

   # All classes automatically get the following methods.
   # The tool generates a file 'canvas.skl' with the skeletons for all
   # these methods.
   # I then implemented those skeletons by hand in 'canvas.imp'.
   param all { draw }

   # Names of the 'new' and 'delete' proc.  These names are
   # suffixed to the class names.
   # Set new_name to "-" or "" if you want to use the class names
   # themselves as constructor names (as in Tk).
   # Set delete_name to "-" if you do not want the delete proc
   # to be generated (which means risking memory leaks!).
   param new_name ""
   param delete_name cdel

   # Name of the 'member' proc.  It allows you to create local
   # variables for some of an object's members.
   # Set member_name to '-' if you do not want it to be generated.
   param member_name mem

   # Name of the 'init' proc, in which each object can initialize itself.
   # This proc is called after the object is created, but before
   # its constructor attributes are configured.
#   param init_name init

   # Set this to 1 to see debugging messages when objects are
   # constructed and deleted.
   param debug 1

   class item {} {
      attr x 0
      attr y 0
      attr tags [list]
   }

   # Class 'volume' inherits from class 'item'.  It adds two
   # additional attributes to the ones it inherits from 'item'.
   class volume {item} {
      attr w 0
      attr h 0
   }

   class axes {volume} {
      attr xname "x"
      attr yname "y"
      attr want_x 1
      attr want_y 1
      attr want_arrow_x 1
      attr want_arrow_y 1
      attr x_clr black
      attr y_clr black
      attr x_thick 1
      attr y_thick 1
   }

   class barchart {volume} {

      # Class 'barchart' contains an instance of class 'axes'.
      # Its name is chosen to be 'axes'.  The generated code allows
      # you to say '$b.axes <methodname>' if 'b' is an instance of 'barchart'.
      contains axes axes
      attr in_color blue
      attr out_color black
      attr values [list]
   }

   # Look in 'try.tcl' to see how the generated code is used.
}

